@@ -203,9 +203,9 @@ def checkCornerBMP(parser): return (
 
 def checkCACertClass3(parser): return (
     checkDisplay(parser, "seq[0]/class", u'universal'),
-    checkDesc(parser, "seq[0]/seq[0]/seq[0]/obj_id[0]", "Object identifier: 1.2.840.113549.1.1.4"),
-    checkValue(parser, "seq[0]/seq[0]/seq[1]/set[0]/seq[0]/print_str[0]/value", u"Root CA"),
-    checkValue(parser, "seq[0]/seq[0]/seq[1]/set[3]/seq[0]/ia5_str[0]/value", u"support@cacert.org"),
+    checkDesc(parser, "seq[0]/seq[0]/seq[1]/obj_id[0]", "Object identifier: 1.2.840.113549.1.1.4"),
+    checkValue(parser, "seq[0]/seq[0]/seq[2]/set[0]/seq[0]/print_str[0]/value", u"Root CA"),
+    checkValue(parser, "seq[0]/seq[0]/seq[2]/set[3]/seq[0]/ia5_str[0]/value", u"support@cacert.org"),
     checkValue(parser, "seq[0]/bit_str[0]/size", 513),
 )
 
@@ -251,7 +251,7 @@ def checkBreakdance(parser): return (
 def checkArpDnsPingDns(parser): return (
     checkValue(parser, "/packet[5]/ipv4/ttl", 120),
     checkDisplay(parser, "/packet[3]/ts_epoch", "2006-11-23 23:13:19"),
-    checkDisplay(parser, "/packet[3]/ipv4/src", "dns2.proxad.net"),
+    checkValue(parser, "/packet[3]/ipv4/src", "212.27.54.252"),
     checkDisplay(parser, "/packet[7]/udp/src", "DNS"),
 )
 
@@ -455,57 +455,11 @@ def checkSevenzipCHM(parser): return (
     checkValue(parser, "/dir/pmgl[0]/entry[1]/name", u"/#IDXHDR"),
 )
 
-testcase_files = (
-    (u"yellowdude.3ds", checkYellowdude),
-    (u"logo-kubuntu.png", checkLogoUbuntu),
-    (u"mbr_linux_and_ext", checkMBR),
-    (u"kde_click.wav", checkClick),
-    (u"test.txt.gz", checkGzip),
-    (u"flashmob.mkv", checkFlashMob),
-    (u"10min.mkv", check10min),
-    (u"cd_0008_5C48_1m53s.cda", checkCDA),
-    (u"wormux_32x32_16c.ico", checkWormuxICO),
-    (u"audio_8khz_8bit_ulaw_4s39.au", checkAU),
-    (u"sheep_on_drugs.mp3", checkSheepMP3),
-    (u"pyc_example_1.5.2.pyc", checkPYC),
-    (u"pyc_example_2.2.3.pyc", checkPYC),
-    (u"pyc_example_2.5c1.pyc", checkPYC),
-    (u"ftp-0.17-537.i586.rpm", checkRPM),
-    (u"jpeg.exif.photoshop.jpg", checkJPEG),
-    (u"small_text.tar", checkTAR),
-    (u"hachoir-core.rar", checkRAR),
-    (u"hachoir-core.ace", checkACE),
-    (u"cacert_class3.der", checkCACertClass3),
-    (u"kde_haypo_corner.bmp", checkCornerBMP),
-    (u"steganography.mp3", checkSteganography),
-    (u"ReferenceMap.class", checkReferenceMapClass),
-    (u"claque-beignet.swf", checkClaqueBeignet),
-    (u"breakdance.flv", checkBreakdance),
-    (u"arp_dns_ping_dns.tcpdump", checkArpDnsPingDns),
-    (u"my60k.ext2", checkExt2),
-    (u"article01.bmp", checkArticle01),
-    (u"reiserfs_v3_332k.bin", checkReiserFS3),
-    (u"lara_croft.pcx", checkLaraCroft),
-    (u"linux_swap_9pages", checkLinuxSwap),
-    (u"pikachu.wmf", checkPikachu),
-    (u"globe.wmf", checkGlobe),
-    (u"indiana.mid", checkIndiana),
-    (u"grasslogo_vector.emf", checkGrassLogo),
-    (u"india_map.gif", checkIndiaMap),
-    (u"cercle.exe", checkCercle),
-    (u"eula.exe", checkEula),
-    (u"ocr10.laf", checkOCR10),
-    (u"kino14s.laf", checkKino14),
-    (u"free-software-song.midi.bz2", checkFreeSoftwareSong),
-    (u"ping_20020927-3ubuntu2", checkPing),
-    (u"georgia.cab", checkGeorgia),
-    (u"debian-31r4-i386-binary-1.iso.torrent", checkDebianTorrent),
-    (u"dell8.fat16", checkDell8FAT16),
-    (u"dontyou.xm", checkXM),
-    (u"satellite_one.s3m", checkS3M),
-    (u"anti-arpeggio_tune.ptm", checkPTM),
-    (u"vim.lnk", checkVimLNK),
-    (u"7zip.chm", checkSevenzipCHM),
+def checkSwat(parser): return (
+    checkValue(parser, "flags", 8),
+    checkValue(parser, "height", 256),
+    checkValue(parser, "width", 256),
+    checkValue(parser, "jpeg_header_len", 10),
 )
 
 def checkFile(filename, check_parser):
@@ -602,6 +556,82 @@ def main():
     print
     print "Result: ok for the %s files" % len(testcase_files)
 
+testcase_files = (
+    (u"yellowdude.3ds", checkYellowdude),
+    (u"logo-kubuntu.png", checkLogoUbuntu),
+    (u"mbr_linux_and_ext", checkMBR),
+    (u"kde_click.wav", checkClick),
+    (u"test.txt.gz", checkGzip),
+    (u"flashmob.mkv", checkFlashMob),
+    (u"10min.mkv", check10min),
+    (u"cd_0008_5C48_1m53s.cda", checkCDA),
+    (u"wormux_32x32_16c.ico", checkWormuxICO),
+    (u"audio_8khz_8bit_ulaw_4s39.au", checkAU),
+    (u"sheep_on_drugs.mp3", checkSheepMP3),
+    (u"pyc_example_1.5.2.pyc", checkPYC),
+    (u"pyc_example_2.2.3.pyc", checkPYC),
+    (u"pyc_example_2.5c1.pyc", checkPYC),
+    (u"ftp-0.17-537.i586.rpm", checkRPM),
+    # cross.xcf
+    (u"jpeg.exif.photoshop.jpg", checkJPEG),
+    (u"small_text.tar", checkTAR),
+    (u"cacert_class3.der", checkCACertClass3),
+    (u"kde_haypo_corner.bmp", checkCornerBMP),
+    # png_331x90x8_truncated.png
+    (u"steganography.mp3", checkSteganography),
+    # smallville.s03e02.avi
+    # 08lechat_hq_fr.mp3
+    (u"ReferenceMap.class", checkReferenceMapClass),
+    (u"claque-beignet.swf", checkClaqueBeignet),
+    # interlude_david_aubrun.ogg
+    (u"breakdance.flv", checkBreakdance),
+    (u"arp_dns_ping_dns.tcpdump", checkArpDnsPingDns),
+    # matrix_ping_pong.wmv
+    # usa_railroad.jpg
+    (u"my60k.ext2", checkExt2),
+    (u"article01.bmp", checkArticle01),
+    (u"reiserfs_v3_332k.bin", checkReiserFS3),
+    (u"lara_croft.pcx", checkLaraCroft),
+    # hero.tga
+    # firstrun.rm
+    (u"linux_swap_9pages", checkLinuxSwap),
+    (u"pikachu.wmf", checkPikachu),
+    (u"globe.wmf", checkGlobe),
+    (u"indiana.mid", checkIndiana),
+    # 25min.aifc
+    (u"grasslogo_vector.emf", checkGrassLogo),
+    (u"ocr10.laf", checkOCR10),
+    (u"kino14s.laf", checkKino14),
+    # ladouce_1h15.wav
+    (u"hachoir-core.ace", checkACE),
+    (u"hachoir-core.rar", checkRAR),
+    (u"debian-31r4-i386-binary-1.iso.torrent", checkDebianTorrent),
+    (u"india_map.gif", checkIndiaMap),
+    (u"cercle.exe", checkCercle),
+    (u"eula.exe", checkEula),
+    (u"free-software-song.midi.bz2", checkFreeSoftwareSong),
+    (u"ping_20020927-3ubuntu2", checkPing),
+    (u"georgia.cab", checkGeorgia),
+    # hachoir.org.sxw
+    (u"dell8.fat16", checkDell8FAT16),
+    (u"dontyou.xm", checkXM),
+    (u"satellite_one.s3m", checkS3M),
+    (u"anti-arpeggio_tune.ptm", checkPTM),
+    # deja_vu_serif-2.7.ttf
+    # twunk_16.exe
+    (u"vim.lnk", checkVimLNK),
+    (u"7zip.chm", checkSevenzipCHM),
+    # green_fire.jpg
+    # marc_kravetz.mp3
+    # pentax_320x240.mov
+    # gps.jpg
+    # angle-bear-48x48.ani
+    # hotel_california.flac
+    # radpoor.doc
+    # quicktime.mp4
+    (u"swat.blp", checkSwat),
+)
+
 if __name__ == "__main__":
     main()
 
